@@ -104,10 +104,9 @@ copy_xattr_list (guestfs_h *g, const struct guestfs_xattr *first, size_t num)
   xattrs->val = safe_malloc (g, num * sizeof (struct guestfs_xattr));
 
   for (i = 0; i < num; ++i) {
-    xattrs->val[i].attrname = strdup (first[i].attrname);
+    xattrs->val[i].attrname    = safe_strdup (g, first[i].attrname);
     xattrs->val[i].attrval_len = first[i].attrval_len;
-    xattrs->val[i].attrval = safe_malloc (g, first[i].attrval_len);
-    memcpy (xattrs->val[i].attrval, first[i].attrval, first[i].attrval_len);
+    xattrs->val[i].attrval     = safe_memdup  (g, first[i].attrval, first[i].attrval_len);
   }
 
   return xattrs;
@@ -133,28 +132,25 @@ mount_local_readdir (const char *path, void *buf, fuse_fill_dir_t filler,
     RETURN_ERRNO;
 
   for (i = 0; i < ents->len; ++i) {
-    struct stat stat;
-    memset (&stat, 0, sizeof stat);
+    struct stat st = (struct stat){
+      .st_ino  = ents->val[i].ino,
+      .st_mode =
+        ents->val[i].ftyp == 'b' ? S_IFBLK  :
+        ents->val[i].ftyp == 'c' ? S_IFCHR  :
+        ents->val[i].ftyp == 'd' ? S_IFDIR  :
+        ents->val[i].ftyp == 'f' ? S_IFIFO  :
+        ents->val[i].ftyp == 'l' ? S_IFLNK  :
+        ents->val[i].ftyp == 'r' ? S_IFREG  :
+        ents->val[i].ftyp == 's' ? S_IFSOCK :
+        /* 'u' and '?' mean "unknown" */
+        0
+    };
 
-    stat.st_ino = ents->val[i].ino;
-    switch (ents->val[i].ftyp) {
-    case 'b': stat.st_mode = S_IFBLK; break;
-    case 'c': stat.st_mode = S_IFCHR; break;
-    case 'd': stat.st_mode = S_IFDIR; break;
-    case 'f': stat.st_mode = S_IFIFO; break;
-    case 'l': stat.st_mode = S_IFLNK; break;
-    case 'r': stat.st_mode = S_IFREG; break;
-    case 's': stat.st_mode = S_IFSOCK; break;
-    case 'u':
-    case '?':
-    default:  stat.st_mode = 0;
-    }
-
-    /* Copied from the example, which also ignores 'offset'.  I'm
+    /* Copied from the example, which also ignores 'offset'. I'm
      * not quite sure how this is ever supposed to work on large
      * directories. XXX
      */
-    if (filler (buf, ents->val[i].name, &stat, 0))
+    if (filler (buf, ents->val[i].name, &st, 0))
       break;
   }
 
@@ -175,33 +171,32 @@ mount_local_readdir (const char *path, void *buf, fuse_fill_dir_t filler,
     if (ss) {
       for (i = 0; i < ss->len; ++i) {
         if (ss->val[i].st_ino >= 0) {
-          struct stat statbuf;
-
-          memset (&statbuf, 0, sizeof statbuf);
-          statbuf.st_dev = ss->val[i].st_dev;
-          statbuf.st_ino = ss->val[i].st_ino;
-          statbuf.st_mode = ss->val[i].st_mode;
-          statbuf.st_nlink = ss->val[i].st_nlink;
-          statbuf.st_uid = ss->val[i].st_uid;
-          statbuf.st_gid = ss->val[i].st_gid;
-          statbuf.st_rdev = ss->val[i].st_rdev;
-          statbuf.st_size = ss->val[i].st_size;
-          statbuf.st_blksize = ss->val[i].st_blksize;
-          statbuf.st_blocks = ss->val[i].st_blocks;
-          statbuf.st_atime = ss->val[i].st_atime_sec;
+          struct stat st = (struct stat){
+            .st_dev      = ss->val[i].st_dev,
+            .st_ino      = ss->val[i].st_ino,
+            .st_mode     = ss->val[i].st_mode,
+            .st_nlink    = ss->val[i].st_nlink,
+            .st_uid      = ss->val[i].st_uid,
+            .st_gid      = ss->val[i].st_gid,
+            .st_rdev     = ss->val[i].st_rdev,
+            .st_size     = ss->val[i].st_size,
+            .st_blksize  = ss->val[i].st_blksize,
+            .st_blocks   = ss->val[i].st_blocks,
+            .st_atime    = ss->val[i].st_atime_sec,
 #ifdef HAVE_STRUCT_STAT_ST_ATIM_TV_NSEC
-          statbuf.st_atim.tv_nsec = ss->val[i].st_atime_nsec;
+            .st_atim.tv_nsec = ss->val[i].st_atime_nsec,
 #endif
-          statbuf.st_mtime = ss->val[i].st_mtime_sec;
+            .st_mtime    = ss->val[i].st_mtime_sec,
 #ifdef HAVE_STRUCT_STAT_ST_MTIM_TV_NSEC
-          statbuf.st_mtim.tv_nsec = ss->val[i].st_mtime_nsec;
+            .st_mtim.tv_nsec = ss->val[i].st_mtime_nsec,
 #endif
-          statbuf.st_ctime = ss->val[i].st_ctime_sec;
+            .st_ctime    = ss->val[i].st_ctime_sec,
 #ifdef HAVE_STRUCT_STAT_ST_CTIM_TV_NSEC
-          statbuf.st_ctim.tv_nsec = ss->val[i].st_ctime_nsec;
+            .st_ctim.tv_nsec = ss->val[i].st_ctime_nsec,
 #endif
+          };
 
-          lsc_insert (g, path, names[i], now, &statbuf);
+          lsc_insert (g, path, names[i], now, &st);
         }
       }
     }
@@ -240,7 +235,7 @@ mount_local_readdir (const char *path, void *buf, fuse_fill_dir_t filler,
           /* which is why we have to free links[i] here. */
           free (links[i]);
       }
-      free (links);             /* free the array, not the strings */
+      free (links); /* free the array, not the strings */
     }
 
     free (names);
@@ -267,29 +262,30 @@ mount_local_getattr (const char *path, struct stat *statbuf)
   if (r == NULL)
     RETURN_ERRNO;
 
-  memset (statbuf, 0, sizeof *statbuf);
-  statbuf->st_dev = r->st_dev;
-  statbuf->st_ino = r->st_ino;
-  statbuf->st_mode = r->st_mode;
-  statbuf->st_nlink = r->st_nlink;
-  statbuf->st_uid = r->st_uid;
-  statbuf->st_gid = r->st_gid;
-  statbuf->st_rdev = r->st_rdev;
-  statbuf->st_size = r->st_size;
-  statbuf->st_blksize = r->st_blksize;
-  statbuf->st_blocks = r->st_blocks;
-  statbuf->st_atime = r->st_atime_sec;
+  *statbuf = (struct stat){
+    .st_dev      = r->st_dev,
+    .st_ino      = r->st_ino,
+    .st_mode     = r->st_mode,
+    .st_nlink    = r->st_nlink,
+    .st_uid      = r->st_uid,
+    .st_gid      = r->st_gid,
+    .st_rdev     = r->st_rdev,
+    .st_size     = r->st_size,
+    .st_blksize  = r->st_blksize,
+    .st_blocks   = r->st_blocks,
+    .st_atime    = r->st_atime_sec,
+    .st_mtime    = r->st_mtime_sec,
+    .st_ctime    = r->st_ctime_sec,
 #ifdef HAVE_STRUCT_STAT_ST_ATIM_TV_NSEC
-  statbuf->st_atim.tv_nsec = r->st_atime_nsec;
+    .st_atim.tv_nsec = r->st_atime_nsec,
 #endif
-  statbuf->st_mtime = r->st_mtime_sec;
 #ifdef HAVE_STRUCT_STAT_ST_MTIM_TV_NSEC
-  statbuf->st_mtim.tv_nsec = r->st_mtime_nsec;
+    .st_mtim.tv_nsec = r->st_mtime_nsec,
 #endif
-  statbuf->st_ctime = r->st_ctime_sec;
 #ifdef HAVE_STRUCT_STAT_ST_CTIM_TV_NSEC
-  statbuf->st_ctim.tv_nsec = r->st_ctime_nsec;
+    .st_ctim.tv_nsec = r->st_ctime_nsec,
 #endif
+  };
 
   return 0;
 }
@@ -708,17 +704,19 @@ mount_local_statfs (const char *path, struct statvfs *stbuf)
   if (r == NULL)
     RETURN_ERRNO;
 
-  stbuf->f_bsize = r->bsize;
-  stbuf->f_frsize = r->frsize;
-  stbuf->f_blocks = r->blocks;
-  stbuf->f_bfree = r->bfree;
-  stbuf->f_bavail = r->bavail;
-  stbuf->f_files = r->files;
-  stbuf->f_ffree = r->ffree;
-  stbuf->f_favail = r->favail;
-  stbuf->f_fsid = r->fsid;
-  stbuf->f_flag = r->flag;
-  stbuf->f_namemax = r->namemax;
+  *stbuf = (struct statvfs){
+    .f_bsize   = r->bsize,
+    .f_frsize  = r->frsize,
+    .f_blocks  = r->blocks,
+    .f_bfree   = r->bfree,
+    .f_bavail  = r->bavail,
+    .f_files   = r->files,
+    .f_ffree   = r->ffree,
+    .f_favail  = r->favail,
+    .f_fsid    = r->fsid,
+    .f_flag    = r->flag,
+    .f_namemax = r->namemax,
+  };
 
   return 0;
 }
