@@ -371,7 +371,7 @@ guestunmount (const char *mp, unsigned flags)
   }
 
   snprintf (cmd, sizeof cmd,
-            "../fuse/guestunmount%s %s",
+            "../fuse/guestunmount%s --retry 10 %s",
             (flags & GUESTUNMOUNT_SILENT) ? " --quiet" : "", mp);
 
   status = system (cmd);
